@@ -21,6 +21,12 @@ def get_parameters(spec):
     return spec.to_dict()["components"]["parameters"]
 
 
+def get_headers(spec):
+    if spec.openapi_version.major < 3:
+        return spec.to_dict()["headers"]
+    return spec.to_dict()["components"]["headers"]
+
+
 def get_examples(spec):
     return spec.to_dict()["components"]["examples"]
 
